Jep 3.2 Release Notes
*********************
This release emphasized bug fixes. It is compatible with Python 2.6 and 2.7.


Improved import hook
~~~~~~~~~~~~~~~~~~~~
The Jep import hook is now more secure, using the supplied ClassLoader to load
Java classes.


JRE included classes
~~~~~~~~~~~~~~~~~~~~
Jep now ships with a list of classes included in the JRE.  This fixes an issue
with inconsistency on imports and enables commands like dir(java.util) from
the Jep interactive console.
